@@ -25,6 +25,7 @@ import { toggleSnackbar } from "../../../actions";
 import API from "../../../middleware/Api";
 import { sizeToString } from "../../../utils";
 import FileFilter from "../Dialogs/FileFilter";
+import { formatLocalTime } from "../../../utils/datetime";
 
 const useStyles = makeStyles((theme) => ({
     root: {
@@ -424,13 +425,10 @@ export default function File() {
                                         </Link>
                                     </TableCell>
                                     <TableCell>
-                                        {new Date(
-                                            row.CreatedAt
-                                        ).toLocaleDateString() +
-                                            " " +
-                                            new Date(
-                                                row.CreatedAt
-                                            ).toLocaleTimeString()}
+                                        {formatLocalTime(
+                                            row.CreatedAt,
+                                            "YYYY-MM-DD H:mm:ss"
+                                        )}
                                     </TableCell>
                                     <TableCell>
                                         <Tooltip title={"删除"}>
