@@ -172,7 +172,7 @@ func (handler Driver) Get(ctx context.Context, path string) (response.RSCloser,
 	}
 
 	// 获取文件数据流
-	client := request.HTTPClient{}
+	client := request.NewClient()
 	resp, err := client.Request(
 		"GET",
 		downloadURL,
@@ -344,6 +344,7 @@ func (handler Driver) Token(ctx context.Context, TTL int64, key string) (seriali
 			map[string]string{"bucket": handler.Policy.BucketName},
 			[]string{"starts-with", "$key", savePath},
 			[]string{"starts-with", "$success_action_redirect", apiURL.String()},
+			[]string{"starts-with", "$name", ""},
 			[]string{"starts-with", "$Content-Type", ""},
 			map[string]string{"x-amz-algorithm": "AWS4-HMAC-SHA256"},
 		},
